@@ -3,5 +3,5 @@
 std::ostream &Scanner::lineMsg()
 {
     Msg::setLine(yylineno);
-    return FBB::lineMsg() << "(" << d_fileInfo.back().first << ") ";
+    return FBB::lineMsg() << "(" << d_fileInfo.back().d_name << ") ";
 }
