@@ -1,16 +1,13 @@
-#ifndef @_h_included
-#define @_h_included
-
-// for error()'s inline implementation
-#include <iostream>
+#ifndef \@_h_included
+#define \@_h_included
 
 $insert baseclass
 $insert scanner.h
 
 $insert namespace-open
 
-#undef @
-class @: public @Base
+#undef \@
+class \@: public \@Base
 {
 $insert 4 scannerobject
         
@@ -26,18 +23,18 @@ $insert 4 scannerobject
     // support functions for parse():
         void executeAction(int ruleNr);
         void errorRecovery();
-        int lookup();
+        int lookup(bool recovery);
         void nextToken();
 };
 
-inline void @::error(char const *msg)
+inline void \@::error(char const *msg)
 {
     std::cerr << msg << std::endl;
 }
 
 $insert lex
 
-inline void @::print()      // use d_token, d_loc
+inline void \@::print()      // use d_token, d_loc
 {}
 
 $insert namespace-close
