@@ -21,7 +21,7 @@ void Writer::srTable(State const *sp, SRContext &context)
 
 
     context.out << "\n"                     // Write the table header
-        "SR s_" << sp->idx() << "[] =\n"
+        "SR__ " << s_threadConst << "s_" << sp->idx() << "[] =\n"
         "{\n";
 
     context.table.clear();
@@ -41,7 +41,7 @@ void Writer::srTable(State const *sp, SRContext &context)
         (defaultReduction ? -static_cast<int>(defaultReduction->nr()) : 0) <<
         def;
 
-    context.out << context.table << "\n"
+    context.out << context.table << // context.table ends in a newline
                    "};\n";
 }
 
